# John's resume!

I am currently making the most programmer'y resume that I can think of. That means I have to do stupid stuff like adding it to pip. Because why not? Wouldn't be much of a developer resume if it doesn't have:
 * Version control
 * Automated tests
 * Full CI/CD pipeline
 * Automatic deployment
 * Legacy support

And more!

This is totally dumb, but if you're interested [head over to my website](https://www.jmgundersen.net/) and let's be dumb together.

Parameters to use this dumb script:
```
 -f : For fast printout
 --json : If you prefer getting the printout in a json format
 -h : for help
```

To run the program just use the command "john-resume":
```
john-resume //Prints the resume
john-resume -f //Prints the resume really fast
```

Note that the script requires an interest connection, as this is an always online service.